@@ -294,6 +294,14 @@ B<-HomeButtonLabel>  The text for the Home directory button. The default is 'Hom
 B<-CWDButtonLabel>  The text for the Current Working Directory button. 
 The default is 'C~WD'.
 
+B<-SortButton>  Whether or not to display a checkbox to change file box list sort order (default=1 show).
+
+B<-SortButtonLabel>  The text for the Sort/Atime button. The default is 'Atime'.
+
+B<-SortOrder>  Order to display files in the file list box ('Name' or 'Date' default=Name).
+If 'Date', then the day and time is displayed in the box before the name, 
+(but not included when selected)
+
 =head2 I<Error Dialog Switches>
 
 If the Create switch is set to 0, and the user specifies a file that does not exist,
@@ -329,11 +337,11 @@ This code may be distributed under the same conditions as Perl itself.
 package Tk::JFileDialog;
 
 use vars qw($VERSION);
-$VERSION = '1.4';
+$VERSION = '1.6';
 
 require 5.002;
 use Tk;
-use Tk::Dialog;
+use Tk::JDialog;
 use Tk::JBrowseEntry;
 use Carp;
 use strict;
@@ -371,11 +379,13 @@ sub Populate
 	my($FDialog, @args) = @_;
 
 	$FDialog->SUPER::Populate(@args);
+	$FDialog->{Configure}{-SortButton} = 1;   #DEFAULT UNLESS SET BY USER TO ZERO!
 	foreach my $i (keys %{$args[0]})
 	{
-		if ($i eq '-HistFile' || $i eq '-History' || $i eq 'QuickSelect'
-				|| $i eq '-PathFile' || $i eq '-HistDeleteOk' 
-				|| $i eq '-HistUsePath' || $i eq '-HistUsePathButton')
+#x		if ($i eq '-HistFile' || $i eq '-History' || $i eq 'QuickSelect'
+#x				|| $i eq '-PathFile' || $i eq '-HistDeleteOk' 
+#x				|| $i eq '-HistUsePath' || $i eq '-HistUsePathButton')
+		if ($i =~ /^\-(?:HistFile|History|QuickSelect|PathFile|HistDeleteOk|HistUsePath|HistUsePathButton|SortButton|SelDir)$/)
 		{
 			$FDialog->{Configure}{$i} = $args[0]->{$i};
 		}
@@ -411,6 +421,7 @@ sub Populate
 	$FDialog->{'DFFrame'} = 0;
 	
 	$FDialog->{Configure}{-Horiz} = 1;
+	$FDialog->{Configure}{-SortOrder} = 'Name';
 	
 	$FDialog->BuildFDWindow;
 	#$FDialog->{'activefore'} = $FDialog->{'SABox'}->cget(-foreground);
@@ -427,6 +438,8 @@ sub Populate
 			-Horiz		=> ['PASSIVE', undef, undef, 1],
 			-Path			=> ['PASSIVE', undef, undef, "$ENV{'HOME'}"],
 			-SelDir		=> ['PASSIVE', undef, undef, 0],
+			-SortButton		=> ['PASSIVE', undef, undef, 1],
+			-SortOrder		=> ['PASSIVE', undef, undef, 'Name'],
 			-DirLBCaption		=> ['PASSIVE', undef, undef, 'Directories:'],
 			-FileLBCaption	=> ['PASSIVE', undef, undef, 'Files:'],
 			-FileEntryLabel	=> ['METHOD', undef, undef, 'Filename:'],
@@ -437,6 +450,7 @@ sub Populate
 			-ShowAllLabel		=> ['METHOD', undef, undef, 'ShowAll'],
 			-OKButtonLabel	=> ['METHOD', undef, undef, '~OK'],
 			-RescanButtonLabel	=> ['METHOD', undef, undef, '~Refresh'],
+			-SortButtonLabel	=> ['METHOD', undef, undef, '~Atime'],
 			-CancelButtonLabel	=> ['METHOD', undef, undef, '~Cancel'],
 			-HomeButtonLabel	=> ['METHOD', undef, undef, '~Home'],
 			-CWDButtonLabel	=> ['METHOD', undef, undef, 'C~WD'],
@@ -450,7 +464,7 @@ sub Populate
 			-HistFile => ['PASSIVE', undef, undef, undef],
 			-HistDeleteOk => ['PASSIVE', undef, undef, undef],
 			-HistUsePath => ['PASSIVE', undef, undef, undef],
-			-HistUsePathButton => ['PASSIVE', undef, undef, undef],
+			-HistUsePathButton => ['PASSIVE', undef, undef, 0],
 			-PathFile => ['PASSIVE', undef, undef, undef],
 			-QuickSelect => ['PASSIVE', undef, undef, 1],
 			-DestroyOnHide => ['PASSIVE', undef, undef, 0],
@@ -468,6 +482,11 @@ sub RescanButtonLabel
 {
 	&SetButton('Rescan',@_);
 }
+sub SortButtonLabel
+{
+	my $self = $_[0];
+	&SetButton('SortxButton',@_)  if (defined $self->{'SortxButton'}) ;
+}
 sub CancelButtonLabel
 {
 	&SetButton('Can',@_);
@@ -615,13 +634,7 @@ sub Show
 				-foreground => $self->{'inactivefore'});
 		$self->{'FileList'}->configure(-selectforeground => $self->{'inactivefore'});
 		$self->{'FileList'}->configure(-foreground => $self->{'inactivefore'});
-	} #else {
-	#$self->{'FileEntry'}->configure(-state => 'normal',
-	#				-foreground => $self->{'activefore'});
-	#$self->{'FileList'}->configure(-selectforeground => $self->{'activefore'});
-	#$self->{'FileList'}->configure(-foreground => $self->{'activefore'});
-	#}
-	
+	}	
 	## Set the title
 	$self->title($self->{Configure}{-Title});
 	
@@ -660,7 +673,7 @@ sub Show
 	{
 		$self->{'FileEntry'}->focus;
 	}
-	
+	select(undef, undef, undef, 0.1)  if ($ENV{DESKTOP_SESSION} =~ /AfterStep version 2.2.1[2-9]/i);  #JWT:ADDED FANCY SLEEP FUNCTION 20140606 B/C TO GET AFTERSTEP TO GIVE "TRANSIENT" WINDOWS THE FOCUS?!;
 	my($i) = 0;
 	while (!$i)
 	{
@@ -839,7 +852,7 @@ sub BindFile
 #			$self->{Configure}{-File} =
 #					$self->{'FileList'}->get($self->{'FileList'}->curselection);
 			#PREV. CHGD. TO NEXT 20050416 TO PERMIT MULTIFILE SELECTIONS, THANKS TO Paul Falbe FOR THIS PATCH!
- 			$self->{Configure}{-File} = join ",", map { $self->{'FileList'}->get($_) }
+ 			$self->{Configure}{-File} = join ",", map { (my $f = $self->{'FileList'}->get($_)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o; $f }
                                                      $self->{'FileList'}->curselection;
 		}
 	}
@@ -854,7 +867,7 @@ sub BindFile
 				my($f) = $self->{'FileList'}->curselection;
 				return if !defined($f);
 				#$self->{'File'} = $self->{'FileList'}->get($f);
-				$self->{Configure}{-File} = $self->{'FileList'}->get($f);
+				($self->{Configure}{-File} = $self->{'FileList'}->get($f)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
 				$self->{'OK'}->invoke;
 			}
 		}
@@ -868,7 +881,7 @@ sub BindFile
 			{
 				my($f) = $self->{'FileList'}->curselection;
 				return if !defined($f);
-				$self->{'File'} = $self->{'FileList'}->get($f);
+				($self->{'File'} = $self->{'FileList'}->get($f)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
 				$self->{'OK'}->invoke;
 			}
 		}
@@ -880,14 +893,14 @@ sub BindFile
 		{
 			my($f) = $self->{'FileList'}->index('active');
 			return if !defined($f);
-			$self->{'File'} = $self->{'FileList'}->get($f);
+			($self->{'File'} = $self->{'FileList'}->get($f)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
 #			$self->{Configure}{-File} = $self->{'FileList'}->get($f);
 			#PREV. CHGD. TO NEXT 20050416 TO PERMIT MULTIFILE SELECTIONS, THANKS TO Paul Falbe FOR THIS PATCH!
- 			$self->{Configure}{-File} = join ",", map { $self->{'FileList'}->get($_) }
+ 			$self->{Configure}{-File} = join ",", map { (my $f = $self->{'FileList'}->get($_)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o; $f }
                                                      $self->{'FileList'}->curselection;
 			$self->{Configure}{-File} ||= $self->{'File'};
 			$self->{'OK'}->focus;
-			$self->{'OK'}->invoke;
+#			$self->{'OK'}->invoke;
 		}
 	}
 	);
@@ -897,10 +910,24 @@ sub BindFile
 		{
 			my($f) = $self->{'FileList'}->index('active');
 			return if !defined($f);
-			$self->{'File'} = $self->{'FileList'}->get($f);
+			($self->{'File'} = $self->{'FileList'}->get($f)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
 #			$self->{Configure}{-File} = $self->{'FileList'}->get($f);
 			#PREV. CHGD. TO NEXT 20050416 TO PERMIT MULTIFILE SELECTIONS, THANKS TO Paul Falbe FOR THIS PATCH!
- 			$self->{Configure}{-File} = join ",", map { $self->{'FileList'}->get($_) }
+ 			$self->{Configure}{-File} = join ",", map { (my $f = $self->{'FileList'}->get($_)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o; $f }
+                                                     $self->{'FileList'}->curselection;
+		}
+	}
+	);
+	$self->{'FileList'}->bind("<Alt-s>", sub
+	{
+		if ($self->{Configure}{-SelDir} != 1)
+		{
+			my($f) = $self->{'FileList'}->index('active');
+			return if !defined($f);
+			($self->{'File'} = $self->{'FileList'}->get($f)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
+#			$self->{Configure}{-File} = $self->{'FileList'}->get($f);
+			#PREV. CHGD. TO NEXT 20050416 TO PERMIT MULTIFILE SELECTIONS, THANKS TO Paul Falbe FOR THIS PATCH!
+ 			$self->{Configure}{-File} = join ",", map { (my $f = $self->{'FileList'}->get($_)) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o; $f }
                                                      $self->{'FileList'}->curselection;
 		}
 	}
@@ -975,7 +1002,7 @@ sub BuildEntry
 	$self->{"$entry"} = $eFrame->Entry(@sunken,
 				-textvariable => \$self->{Configure}{$LabelVar})
 			->pack(@leftPack, @expand, @xfill);
-	if ($LabelType eq 'File' && $self->{Configure}{-SelDir} != 1)
+	if ($LabelType eq 'File' && (!defined($self->{Configure}{-SelDir}) || $self->{Configure}{-SelDir} != 1))
 	{
 		$self->{"$entry"}->bind("<Return>",sub
 		{
@@ -986,6 +1013,14 @@ sub BuildEntry
 	#elsif ($LabelType eq 'Path' && $self->{Configure}{-SelDir})
 	elsif ($LabelType eq 'Path')
 	{
+		if ($self->{Configure}{-SortButton})
+		{
+			$self->{'SortxButton'} = $eFrame->Checkbutton( -variable => \$self->{Configure}{-SortOrder},
+				-onvalue => 'Date', -offvalue => 'Name',
+				-text => 'Atime',
+				-command => sub { &SortFiles($self);})
+				->pack(@leftPack);
+		}
 		$self->{"$entry"}->bind("<Return>",sub
 			{
 				&RescanFiles($self);
@@ -1006,13 +1041,14 @@ sub BuildEntry
 		if (length($currentval))    #ADDED 20010131
 		{
 			$oldval = $currentval;
-			$currentval = ''  unless ($currentval =~ m|/|);
-			$currentval =~ s|(.*\/)(.*)$|$1|;
-			$_ = $self->{$whichlist}->get('active');
+			$currentval = ''  unless ($currentval =~ m#\/#o);
+			$currentval =~ s#(.*\/)(.*)$#$1#;
+			($_ = $self->{$whichlist}->get('active')) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
 			my ($restofsel) = $currentval;
 			if ($_ && $_ ne '.' && $_ ne '..' && $_ ne '/')   #IF ADDED 20010131.
 			{
-				$restofsel .= $self->{$whichlist}->get('active');
+				($_ = $self->{$whichlist}->get('active')) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
+				$restofsel .= $_;
 			}
 #			elsif ($_ eq '..' && $restofsel ne $oldval)
 #			{
@@ -1027,10 +1063,12 @@ sub BuildEntry
 	{
 		my ($currentval);
 		$currentval = $self->{"$entry"}->get;
-		$currentval = ''  unless ($currentval =~ m|/|);
-		$currentval =~ s|(.*\/)(.*)$|$1|;
+		$currentval = ''  unless ($currentval =~ m#\/#);
+		$currentval =~ s#(.*\/)(.*)$#$1#;
 		$self->{$whichlist}->UpDown(-1);
-		my ($restofsel) = $currentval . $self->{$whichlist}->get('active');
+		my ($restofsel) = $currentval;
+		($_ = $self->{$whichlist}->get('active')) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
+		$restofsel .= $_;
 		$self->{$entry}->delete('0.0','end');
 		$self->{$entry}->insert('end',$restofsel);
 		Tk->break;
@@ -1040,10 +1078,12 @@ sub BuildEntry
 	{
 		my ($currentval);
 		$currentval = $self->{"$entry"}->get;
-		$currentval = ''  unless ($currentval =~ m|/|);
-		$currentval =~ s|(.*\/)(.*)$|$1|;
+		$currentval = ''  unless ($currentval =~ m#\/#);
+		$currentval =~ s#(.*\/)(.*)$#$1#;
 		$self->{$whichlist}->UpDown(1);
-		my ($restofsel) = $currentval . $self->{$whichlist}->get('active');
+		my ($restofsel) = $currentval;
+		($_ = $self->{$whichlist}->get('active')) =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
+		$restofsel .= $_;
 		$self->{$entry}->delete('0.0','end');
 		$self->{$entry}->insert('end',$restofsel);
 		Tk->break;
@@ -1081,7 +1121,7 @@ sub BuildBrowse
 
 	if ($LabelVar eq '-Hist')
 	{
-		$self->{"histToggleVal"} = ($self->{Configure}{-HistUsePathButton} == 1) ? 1 : 0;
+		$self->{"histToggleVal"} = (defined($self->{Configure}{-HistUsePathButton}) && $self->{Configure}{-HistUsePathButton} == 1) ? 1 : 0;
 		if ($self->{Configure}{-HistUsePath}  && $self->{Configure}{-HistUsePath} != 1)
 		{
 			my $pathLabel = $self->{Configure}{-HistUsePath};
@@ -1191,7 +1231,7 @@ sub BuildFAV
 			{
 				$l = $_;
 				$r = '';
-				($l,$r) = split(/\;/);
+				($l,$r) = split(/\;/o);
 				$r ||= $l;
 				${$self->{Configure}{PathList}}{$l} = $r;
 			}
@@ -1249,7 +1289,6 @@ sub BuildFDWindow
 {
 	### Build the entire file dialog window
 	my($self) = shift;
-	
 	### Build the filename entry box
 	$self->{'FEF'} = &BuildEntry($self, 'File', 'FileEntry');
 	
@@ -1268,11 +1307,11 @@ sub BuildFDWindow
 	## Now the entry...
 	$self->{'FPat'} = $patFrame->Entry(-textvariable => \$self->{Configure}{-FPat})
 			->pack(@leftPack, @expand, @xfill);
-	$self->{'FPat'}->bind("<Return>",sub {\&RescanFiles($self);});
+	$self->{'FPat'}->bind("<Return>",sub { &RescanFiles($self);});
 	
 	## and the radio box
 	$self->{'SABox'} = $patFrame->Checkbutton(-variable => \$self->{Configure}{-ShowAll},
-			-command => sub {\&RescanFiles($self);})
+			-command => sub { &RescanFiles($self);})
 			->pack(@leftPack);
 	
 	### JWT:Build the Favorites Dropdown list.
@@ -1284,14 +1323,14 @@ sub BuildFDWindow
 	
 	$self->{'OK'} = $butFrame->Button(-command => sub
 	{
-		\&GetReturn($self);
+		&GetReturn($self);
 	}
 	)
 			->pack(-padx => '2m', -pady => '2m', @leftPack, @expand, @xfill);
 	
 	$self->{'Rescan'} = $butFrame->Button(-command => sub
 	{
-		\&RescanFiles($self);
+		&RescanFiles($self);
 	}
 	)
 			->pack(-padx => '2m', -pady => '2m', @leftPack, @expand, @xfill);
@@ -1308,11 +1347,11 @@ sub BuildFDWindow
 		-command => sub
 		{
 			$self->{Configure}{-Path} = $ENV{HOME} || $ENV{LOGDIR};
-			$self->{Configure}{-Path} =~ s#\\#\/#g;
+			$self->{Configure}{-Path} =~ s#\\#\/#go;
 			$self->{Configure}{-Path} = (getpwuid($<))[7]
 					unless ($Win32 || !$< || $self->{Configure}{-Path});
 			$self->{Configure}{-Path} ||= &cwd() || &getcwd();
-			\&RescanFiles($self);
+			&RescanFiles($self);
 		}
 	)->pack(-padx => '2m', -pady => '2m', @leftPack, @expand, @xfill);
 	
@@ -1322,8 +1361,8 @@ sub BuildFDWindow
 		-command => sub
 		{
 			$self->{Configure}{-Path} = &cwd() || &getcwd();
-			$self->{Configure}{-Path} =~ s#\\#\/#g;
-			\&RescanFiles($self);
+			$self->{Configure}{-Path} =~ s#\\#\/#go;
+			&RescanFiles($self);
 		}
 	)->pack(-padx => '2m', -pady => '2m', @leftPack, @expand, @xfill);
 	
@@ -1342,8 +1381,8 @@ sub BuildFDWindow
 				-command => sub
 				{
 					$self->{Configure}{-Path} = $cdir;
-					$self->{Configure}{-Path} =~ s#\\#\/#g;
-					\&RescanFiles($self);
+					$self->{Configure}{-Path} =~ s#\\#\/#go;
+					&RescanFiles($self);
 				}
 			)->pack(-padx => '2m', -pady => '2m', @leftPack, @expand, @xfill);
 		}
@@ -1384,7 +1423,7 @@ sub RescanFiles
 	}
 	else
 	{
-		if ($path =~ /^~/)
+		if ($path =~ /^~/o)
 		{
 			$path = `ls -d $path`;   # !!! HANDLES DIRS W/ A TILDE!
 			chomp($path);
@@ -1397,7 +1436,7 @@ sub RescanFiles
 	}
 	### path now has a trailing / no matter what
 
-	unless (($path =~ /^~/) || -d $path)
+	unless (($path =~ /^~/o) || -d $path)
 	{
 		print STDERR "-JFileDialog: =$path= is NOT a directory\n";
 		carp "$path is NOT a directory\n";
@@ -1435,11 +1474,11 @@ sub RescanFiles
 			}
 			next  if ($direntry eq '..' && $path eq '/');
 			$dl->insert('end',$direntry);
-			$parentfound = 1  if ($direntry =~ /^\.\./);
+			$parentfound = 1  if ($direntry =~ /^\.\./o);
 		}
 		$dl->insert(1,'..')   #ADDED 20010130 JWT TO FIX MISSING ".." CHOICE!
-				unless ($parentfound || $path eq '/' || ($path =~ m#^\w\:\/?$#));
-		$dl->insert(1,'.')  if ($path eq '/' || ($path =~ m#^\w\:\/?$#));
+				unless ($parentfound || $path eq '/' || ($path =~ m#^\w\:\/?$#o));
+		$dl->insert(1,'.')  if ($path eq '/' || ($path =~ m#^\w\:\/?$#o));
 	}
 	
 	## Now, get the files
@@ -1460,12 +1499,47 @@ sub RescanFiles
 		@allfiles = grep { /\.${pat}$/i } readdir(DIR);
 		closedir DIR;
 	}
-	foreach $direntry (sort @allfiles)
+	if ($self->{Configure}{-SortOrder} =~ /^N/o)
 	{
-		if (-f "${path}$direntry")
+		foreach $direntry (sort @allfiles)
+		{
+			if (-f "${path}$direntry")
+			{
+				$direntry =~ s!.*/([^/]*)$!$1!;
+				next  if (!$show && $direntry =~ /^\./o);  #SKIP ".-FILES" EVEN ON WINDOWS!
+				$fl->insert('end',$direntry);
+			}
+		}
+	}
+	else
+	{
+
+		my @sortedFiles;
+		foreach $direntry (@allfiles)
+		{
+			if (-f "${path}$direntry")
+			{
+				my (@timestuff, @stats, $atime);
+				@stats = stat "${path}$direntry";
+				@timestuff = localtime($stats[9]);
+				$atime = ($timestuff[5] + 1900);
+				$atime .= '0'  if ($timestuff[4] < 9);
+				$atime .= ($timestuff[4] + 1);
+				$atime .= '0'  if ($timestuff[3] < 10);
+				$atime .= $timestuff[3];
+				$atime .= ' ';
+				$atime .= '0'  if ($timestuff[2] < 10);
+				$atime .= $timestuff[2];
+				$atime .= '0'  if ($timestuff[1] < 10);
+				$atime .= $timestuff[1];
+				$direntry =~ s!.*/([^/]*)$!$1!;
+				next  if (!$show && $direntry =~ /^\./o);  #SKIP ".-FILES" EVEN ON WINDOWS!
+				push @sortedFiles, ($atime . ' ' . $direntry);
+			}
+		}
+		my @stats;
+		foreach $direntry (sort @sortedFiles)
 		{
-			$direntry =~ s!.*/([^/]*)$!$1!;
-			next  if (!$show && $direntry =~ /^\./);  #SKIP ".-FILES" EVEN ON WINDOWS!
 			$fl->insert('end',$direntry);
 		}
 	}
@@ -1559,6 +1633,7 @@ sub GetReturn
 			if (defined($fname->curselection))
 			{
 				$fname = $fname->get($fname->curselection);
+				$fname =~ s/^\d\d\d\d\d\d\d\d \d\d \d\d//o;
 				if ($fname =~ /^\.\.$/)   # !!!
 				{
 					$path =~ s/\/$//;
@@ -1608,7 +1683,7 @@ sub GetReturn
 				my($file) = $self->{Configure}{-File};
 				my($filename) = $fname;
 				eval "\$fname = \"$self->{Configure}{-EDlgText}\"";
-				$self->Dialog(-title => $self->{Configure}{-EDlgTitle},
+				$self->JDialog(-title => $self->{Configure}{-EDlgTitle},
 						-text => $fname,
 						-bitmap => 'error')
 						->Show;
@@ -1640,6 +1715,7 @@ sub GetReturn
 					$path =~ s/\/$//;
 					$path =~ s#/[^/]*$#/#;
 				}
+				$fname =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
 			}
 			else
 			{
@@ -1697,7 +1773,7 @@ sub GetReturn
 				my($file) = $self->{Configure}{-File};
 				my($filename) = $fname;
 				eval "\$fname = \"$self->{Configure}{-EDlgText}\"";
-				$self->Dialog(-title => $self->{Configure}{-EDlgTitle},
+				$self->JDialog(-title => $self->{Configure}{-EDlgTitle},
 						-text => $fname,
 						-bitmap => 'error')
 						->Show;
@@ -1720,7 +1796,7 @@ sub keyFn    #JWT: TRAP LETTERS PRESSED AND ADJUST SELECTION ACCORDINGLY.
 	if ($mykey)
 	{
 		my ($entryval) = $e->get;
-		$entryval =~ s|(.*/)(.*)$|$2|;
+		$entryval =~ s#(.*/)(.*)$#$2#;
 		&LbFindSelection($l,$entryval);
 	}
 	#	}
@@ -1747,6 +1823,13 @@ sub LbFindSelection
 	$l->configure(-selectmode => 'browse')
 			if ($l->{Configure}{-selectmode} eq 'single');
 	my (@listsels) = $l->get('0','end');
+	if ($#listsels >= 0 && $listsels[0] =~ /^\d\d\d\d\d\d\d\d \d\d\d\d /)
+	{
+		foreach my $i (0..$#listsels)
+		{
+			$listsels[$i] =~ s/^\d\d\d\d\d\d\d\d \d\d\d\d //o;
+		}
+	}
 	foreach my $i (0..$#listsels)
 	{
 		if ($listsels[$i] eq $srchval)
@@ -1806,6 +1889,13 @@ sub chgDriveLetter   #ADDED 20010130 BY JWT.
 	&RescanFiles($self);
 }
 
+sub SortFiles
+{
+	my ($self) = shift;
+
+	&RescanFiles($self);
+}
+
 ### Return 1 to the calling  use statement ###
 1;
 ### End of file FileDialog.pm ###
